package com.tzld.piaoquan.wecom.job;

import com.alibaba.fastjson.JSONObject;
import com.tzld.piaoquan.wecom.dao.mapper.UserMapper;
import com.tzld.piaoquan.wecom.model.po.User;
import com.tzld.piaoquan.wecom.model.po.UserExample;
import com.tzld.piaoquan.wecom.service.AccessTokenService;
import com.tzld.piaoquan.wecom.utils.HttpClientUtil;
import com.tzld.piaoquan.wecom.utils.HttpPoolClient;
import com.tzld.piaoquan.wecom.utils.page.Page;
import com.xxl.job.core.biz.model.ReturnT;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

@Slf4j
@Component
public class WeComUserDataJob1 {

    private static final HttpPoolClient httpPoolClientDefault = HttpClientUtil.create(30000, 30000, 2000, 5000, 5, 30000);


    @Autowired
    private UserMapper userMapper;
    @Autowired
    private AccessTokenService accessTokenService;

    @XxlJob("setExternalUserIdJob")
    public ReturnT<String> setExternalUserId(String param) throws IOException {
        try {
            UserExample example = new UserExample();
            long count = userMapper.countByExample(example);
            int page = 1;
            int pageSize = 1000;
            long totalPageSize = count / pageSize + 1;
            for (; page <= totalPageSize; page++) {
                example.setPage(new Page<>(page, pageSize));
                List<User> userList = userMapper.selectByExample(example);
                if (CollectionUtils.isEmpty(userList)) {
                    continue;
                }
                for (User user : userList) {
                    String externalUserId3rdParty = user.getExternalUserId3rdParty();
                    String externalUserId = getExternalUserId(externalUserId3rdParty);
                    if (StringUtils.isEmpty(externalUserId)) {
                        continue;
                    }
                    User updateUser = new User();
                    updateUser.setId(user.getId());
                    updateUser.setExternalUserId(externalUserId);
                    userMapper.updateByPrimaryKeySelective(updateUser);
                }
            }
        } catch (Exception e) {
            log.error("setExternalUserId error", e);
        }

        return ReturnT.SUCCESS;
    }

    private String getExternalUserId(String externalUserId3rdParty) throws IOException {
        String weComAccessToken = accessTokenService.getWeComAccessToken();
        String url = String.format("https://qyapi.weixin.qq.com/cgi-bin/externalcontact/from_service_external_userid?access_token=%s", weComAccessToken);
        JSONObject param = new JSONObject();
        param.put("external_userid", externalUserId3rdParty);
        param.put("source_agentid", 1000009);
        String res = httpPoolClientDefault.post(url, param.toJSONString());
        JSONObject jsonObject = JSONObject.parseObject(res);
        Integer errcode = jsonObject.getInteger("errcode");
        if (errcode == 0) {
            return jsonObject.getString("external_userid");
        }
        return null;
    }


}
